@@ -160,7 +160,7 @@ MainWindow::initLogging ()
                         this     , SLOT(onCleanupLogsArray()));
     Q_ASSERT(rv); Q_UNUSED(rv);
 
-    setStatus("Using qgvdial version 0.2.764");
+    setStatus("Using qgvdial version 0.2.773");
 }//MainWindow::initLogging
 
 /** Log information to console and to log file
@@ -510,7 +510,7 @@ MainWindow::init ()
                   &oInbox   , SLOT  (refresh(const QDateTime &)));
     Q_ASSERT(rv);
     rv = connect (&mqThread , SIGNAL(sigUpdateContacts(const QDateTime &)),
-                  &oContacts, SLOT  (refreshContacts(const QDateTime &)));
+                  &oContacts, SLOT  (mqUpdateContacts(const QDateTime &)));
     Q_ASSERT(rv);
     rv = connect (&mqThread , SIGNAL(status(QString,int)),
                    this     , SLOT  (setStatus(QString,int)));
@@ -545,6 +545,7 @@ MainWindow::initQML ()
 {
     qmlRegisterType<WebWidget>("org.qgvdial.WebWidget", 1, 0, "MyWebWidget");
 
+    OsDependent &osd = Singletons::getRef().getOSD ();
     bool bTempFalse = false;
     int iTempZero = 0;
 
@@ -561,21 +562,10 @@ MainWindow::initQML ()
     ctx->setContextProperty ("g_logModel", QVariant::fromValue(arrLogMsgs));
 
     // Initialize the QML view
-#if defined(MEEGO_HARMATTAN)
-    this->setSource (QUrl ("qrc:/HMain.qml"));
-#else
-    this->setSource (QUrl ("qrc:/Main.qml"));
-#endif
+    this->setSource (QUrl(osd.getMainQML()));
 
     onDesktopResized ();
-
-#if 0 && defined(MEEGO_HARMATTAN)
-    // Do rotate
-    QMetaObject::invokeMethod (this->rootObject(), "doRotate",
-                        Q_ARG (QVariant, QVariant(-90.0)));
-#else
     this->setResizeMode (QDeclarativeView::SizeRootObjectToView);
-#endif
 
     this->setUsername ("example@gmail.com");
     this->setPassword ("hunter2 :p");
@@ -928,6 +918,7 @@ MainWindow::on_actionE_xit_triggered ()
 #if MOSQUITTO_CAPABLE
     mqThread.setQuit ();
 #endif
+
     qApp->quit ();
 }//MainWindow::on_actionE_xit_triggered
 
@@ -2124,19 +2115,16 @@ MainWindow::onTwoStepAuthentication(QString &result)
 void
 MainWindow::onDesktopResized()
 {
+    QObject *pMain = this->rootObject ();
+    if (NULL == pMain) {
+        qWarning ("Could not get to MainPage for resize");
+        return;
+    }
+
     OsDependent &osd = Singletons::getRef().getOSD ();
-    QRect rect = osd.getStartingSize (this);
-
-    do { // Begin cleanup block (not a loop)
-        QObject *pMain = this->rootObject ();
-        if (NULL == pMain) {
-            qWarning ("Could not get to MainPage for resize");
-            break;
-        }
-
-        pMain->setProperty("height", rect.height());
-        pMain->setProperty("width", rect.width());
-    } while (0); // End cleanup block (not a loop)
+    QRect rect = osd.getStartingSize ();
+    pMain->setProperty("height", rect.height());
+    pMain->setProperty("width", rect.width());
 }//MainWindow::onDesktopResized
 
 QObject *
