@@ -1,3 +1,24 @@
+/*
+qgvdial is a cross platform Google Voice Dialer
+Copyright (C) 2010  Yuvraaj Kelkar
+
+This library is free software; you can redistribute it and/or
+modify it under the terms of the GNU Lesser General Public
+License as published by the Free Software Foundation; either
+version 2.1 of the License, or (at your option) any later version.
+
+This library is distributed in the hope that it will be useful,
+but WITHOUT ANY WARRANTY; without even the implied warranty of
+MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+Lesser General Public License for more details.
+
+You should have received a copy of the GNU Lesser General Public
+License along with this library; if not, write to the Free Software
+Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+
+Contact: yuvraaj@gmail.com
+*/
+
 #include "SymbianCallInitiator.h"
 #include "SymbianCallInitiatorPrivate.h"
 #include "SymbianCallObserverPrivate.h"
@@ -11,9 +32,6 @@ SymbianCallInitiator::SymbianCallInitiator (QObject *parent)
 {
     iTelephony = CTelephony::NewL();
     dtmfSender = new SymbianDTMFPrivate (this);
-    if (NULL != iTelephony) {
-        delete iTelephony;
-    }
 }//SymbianCallInitiator::SymbianCallInitiator
 
 SymbianCallInitiator::~SymbianCallInitiator()
@@ -27,6 +45,9 @@ SymbianCallInitiator::~SymbianCallInitiator()
     if (NULL != dtmfSender) {
         delete dtmfSender;
     }
+    if (NULL != iTelephony) {
+        delete iTelephony;
+    }
 }//SymbianCallInitiator::~SymbianCallInitiator
 
 QString
@@ -38,7 +59,7 @@ SymbianCallInitiator::name ()
 QString
 SymbianCallInitiator::selfNumber ()
 {
-    return "This phone's MSISDN";
+    return "This phone's number";
 }//SymbianCallInitiator::selfNumber
 
 bool
@@ -69,6 +90,8 @@ SymbianCallInitiator::initiateCall (const QString &strDestination,
 
         dialer = SymbianCallInitiatorPrivate::NewL (this, strDestination);
         if (NULL == dialer) {
+            delete observer;
+            observer = NULL;
             qWarning ("Could not dial out.");
             break;  // false
         }
@@ -87,17 +110,19 @@ SymbianCallInitiator::callDone (SymbianCallInitiatorPrivate *self, int status)
     QMutexLocker locker(&mutex);
     strObservedNumber.clear ();
 
-    if (dialer == self) {
-        dialer = NULL;
-
-        if (NULL != observer) {
-            delete observer;
-            observer = NULL;
-        }
-    } else {
-        qWarning ("Dialer does not match!!!");
+    if (NULL != observer) {
+        delete observer;
+        observer = NULL;
     }
 
+    if (dialer != self) {
+        qWarning ("Dialer does not match!!!");
+        if (NULL != dialer) {
+            delete dialer;
+        }
+    }
+    dialer = NULL;
+
     emit callInitiated ((status == KErrNone), m_Context);
 }//SymbianCallInitiator::callDone
 
